# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from qaseio.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from qaseio.model.attachment import Attachment
from qaseio.model.attachment_get import AttachmentGet
from qaseio.model.attachment_hash import AttachmentHash
from qaseio.model.attachment_hash_list import AttachmentHashList
from qaseio.model.attachment_list_response import AttachmentListResponse
from qaseio.model.attachment_list_response_all_of import AttachmentListResponseAllOf
from qaseio.model.attachment_list_response_all_of_result import AttachmentListResponseAllOfResult
from qaseio.model.attachment_response import AttachmentResponse
from qaseio.model.attachment_response_all_of import AttachmentResponseAllOf
from qaseio.model.attachment_uploads_response import AttachmentUploadsResponse
from qaseio.model.attachment_uploads_response_all_of import AttachmentUploadsResponseAllOf
from qaseio.model.author import Author
from qaseio.model.author_list_response import AuthorListResponse
from qaseio.model.author_list_response_all_of import AuthorListResponseAllOf
from qaseio.model.author_list_response_all_of_result import AuthorListResponseAllOfResult
from qaseio.model.author_response import AuthorResponse
from qaseio.model.author_response_all_of import AuthorResponseAllOf
from qaseio.model.bulk200_response import Bulk200Response
from qaseio.model.bulk200_response_all_of import Bulk200ResponseAllOf
from qaseio.model.bulk200_response_all_of_result import Bulk200ResponseAllOfResult
from qaseio.model.bulk_request import BulkRequest
from qaseio.model.bulk_request_cases_inner import BulkRequestCasesInner
from qaseio.model.bulk_request_cases_inner_all_of import BulkRequestCasesInnerAllOf
from qaseio.model.create_result200_response import CreateResult200Response
from qaseio.model.create_result200_response_all_of import CreateResult200ResponseAllOf
from qaseio.model.create_result200_response_all_of_result import CreateResult200ResponseAllOfResult
from qaseio.model.create_results_request_v2 import CreateResultsRequestV2
from qaseio.model.create_results_request_v2_results_inner import CreateResultsRequestV2ResultsInner
from qaseio.model.custom_field import CustomField
from qaseio.model.custom_field_create import CustomFieldCreate
from qaseio.model.custom_field_create_value_inner import CustomFieldCreateValueInner
from qaseio.model.custom_field_response import CustomFieldResponse
from qaseio.model.custom_field_response_all_of import CustomFieldResponseAllOf
from qaseio.model.custom_field_update import CustomFieldUpdate
from qaseio.model.custom_field_value import CustomFieldValue
from qaseio.model.custom_fields_response import CustomFieldsResponse
from qaseio.model.custom_fields_response_all_of import CustomFieldsResponseAllOf
from qaseio.model.custom_fields_response_all_of_result import CustomFieldsResponseAllOfResult
from qaseio.model.defect import Defect
from qaseio.model.defect_create import DefectCreate
from qaseio.model.defect_list_response import DefectListResponse
from qaseio.model.defect_list_response_all_of import DefectListResponseAllOf
from qaseio.model.defect_list_response_all_of_result import DefectListResponseAllOfResult
from qaseio.model.defect_response import DefectResponse
from qaseio.model.defect_response_all_of import DefectResponseAllOf
from qaseio.model.defect_status import DefectStatus
from qaseio.model.defect_update import DefectUpdate
from qaseio.model.environment import Environment
from qaseio.model.environment_create import EnvironmentCreate
from qaseio.model.environment_list_response import EnvironmentListResponse
from qaseio.model.environment_list_response_all_of import EnvironmentListResponseAllOf
from qaseio.model.environment_list_response_all_of_result import EnvironmentListResponseAllOfResult
from qaseio.model.environment_response import EnvironmentResponse
from qaseio.model.environment_response_all_of import EnvironmentResponseAllOf
from qaseio.model.environment_update import EnvironmentUpdate
from qaseio.model.hash_response import HashResponse
from qaseio.model.hash_response_all_of import HashResponseAllOf
from qaseio.model.hash_response_all_of_result import HashResponseAllOfResult
from qaseio.model.id_response import IdResponse
from qaseio.model.id_response_all_of import IdResponseAllOf
from qaseio.model.id_response_all_of_result import IdResponseAllOfResult
from qaseio.model.milestone import Milestone
from qaseio.model.milestone_create import MilestoneCreate
from qaseio.model.milestone_list_response import MilestoneListResponse
from qaseio.model.milestone_list_response_all_of import MilestoneListResponseAllOf
from qaseio.model.milestone_list_response_all_of_result import MilestoneListResponseAllOfResult
from qaseio.model.milestone_response import MilestoneResponse
from qaseio.model.milestone_response_all_of import MilestoneResponseAllOf
from qaseio.model.milestone_update import MilestoneUpdate
from qaseio.model.plan import Plan
from qaseio.model.plan_create import PlanCreate
from qaseio.model.plan_detailed import PlanDetailed
from qaseio.model.plan_detailed_all_of import PlanDetailedAllOf
from qaseio.model.plan_detailed_all_of_cases import PlanDetailedAllOfCases
from qaseio.model.plan_list_response import PlanListResponse
from qaseio.model.plan_list_response_all_of import PlanListResponseAllOf
from qaseio.model.plan_list_response_all_of_result import PlanListResponseAllOfResult
from qaseio.model.plan_response import PlanResponse
from qaseio.model.plan_response_all_of import PlanResponseAllOf
from qaseio.model.plan_update import PlanUpdate
from qaseio.model.project import Project
from qaseio.model.project_access import ProjectAccess
from qaseio.model.project_code_response import ProjectCodeResponse
from qaseio.model.project_code_response_all_of import ProjectCodeResponseAllOf
from qaseio.model.project_code_response_all_of_result import ProjectCodeResponseAllOfResult
from qaseio.model.project_counts import ProjectCounts
from qaseio.model.project_counts_defects import ProjectCountsDefects
from qaseio.model.project_counts_runs import ProjectCountsRuns
from qaseio.model.project_create import ProjectCreate
from qaseio.model.project_list_response import ProjectListResponse
from qaseio.model.project_list_response_all_of import ProjectListResponseAllOf
from qaseio.model.project_list_response_all_of_result import ProjectListResponseAllOfResult
from qaseio.model.project_response import ProjectResponse
from qaseio.model.project_response_all_of import ProjectResponseAllOf
from qaseio.model.qql_defect import QqlDefect
from qaseio.model.qql_plan import QqlPlan
from qaseio.model.qql_test_case import QqlTestCase
from qaseio.model.relation_suite import RelationSuite
from qaseio.model.relation_suite_item import RelationSuiteItem
from qaseio.model.requirement import Requirement
from qaseio.model.response import Response
from qaseio.model.result import Result
from qaseio.model.result_attachment import ResultAttachment
from qaseio.model.result_create import ResultCreate
from qaseio.model.result_create_bulk import ResultCreateBulk
from qaseio.model.result_create_case import ResultCreateCase
from qaseio.model.result_execution import ResultExecution
from qaseio.model.result_list_response import ResultListResponse
from qaseio.model.result_list_response_all_of import ResultListResponseAllOf
from qaseio.model.result_list_response_all_of_result import ResultListResponseAllOfResult
from qaseio.model.result_relations import ResultRelations
from qaseio.model.result_response import ResultResponse
from qaseio.model.result_response_all_of import ResultResponseAllOf
from qaseio.model.result_step import ResultStep
from qaseio.model.result_step_data import ResultStepData
from qaseio.model.result_step_execution import ResultStepExecution
from qaseio.model.result_update import ResultUpdate
from qaseio.model.run import Run
from qaseio.model.run_create import RunCreate
from qaseio.model.run_environment import RunEnvironment
from qaseio.model.run_list_response import RunListResponse
from qaseio.model.run_list_response_all_of import RunListResponseAllOf
from qaseio.model.run_list_response_all_of_result import RunListResponseAllOfResult
from qaseio.model.run_milestone import RunMilestone
from qaseio.model.run_public import RunPublic
from qaseio.model.run_public_response import RunPublicResponse
from qaseio.model.run_public_response_all_of import RunPublicResponseAllOf
from qaseio.model.run_public_response_all_of_result import RunPublicResponseAllOfResult
from qaseio.model.run_response import RunResponse
from qaseio.model.run_response_all_of import RunResponseAllOf
from qaseio.model.run_stats import RunStats
from qaseio.model.search_response import SearchResponse
from qaseio.model.search_response_all_of import SearchResponseAllOf
from qaseio.model.search_response_all_of_result import SearchResponseAllOfResult
from qaseio.model.shared_step import SharedStep
from qaseio.model.shared_step_content import SharedStepContent
from qaseio.model.shared_step_content_create import SharedStepContentCreate
from qaseio.model.shared_step_create import SharedStepCreate
from qaseio.model.shared_step_list_response import SharedStepListResponse
from qaseio.model.shared_step_list_response_all_of import SharedStepListResponseAllOf
from qaseio.model.shared_step_list_response_all_of_result import SharedStepListResponseAllOfResult
from qaseio.model.shared_step_response import SharedStepResponse
from qaseio.model.shared_step_response_all_of import SharedStepResponseAllOf
from qaseio.model.shared_step_update import SharedStepUpdate
from qaseio.model.suite import Suite
from qaseio.model.suite_create import SuiteCreate
from qaseio.model.suite_delete import SuiteDelete
from qaseio.model.suite_list_response import SuiteListResponse
from qaseio.model.suite_list_response_all_of import SuiteListResponseAllOf
from qaseio.model.suite_list_response_all_of_result import SuiteListResponseAllOfResult
from qaseio.model.suite_response import SuiteResponse
from qaseio.model.suite_response_all_of import SuiteResponseAllOf
from qaseio.model.suite_update import SuiteUpdate
from qaseio.model.tag_value import TagValue
from qaseio.model.test_case import TestCase
from qaseio.model.test_case_create import TestCaseCreate
from qaseio.model.test_case_list_response import TestCaseListResponse
from qaseio.model.test_case_list_response_all_of import TestCaseListResponseAllOf
from qaseio.model.test_case_list_response_all_of_result import TestCaseListResponseAllOfResult
from qaseio.model.test_case_params import TestCaseParams
from qaseio.model.test_case_response import TestCaseResponse
from qaseio.model.test_case_response_all_of import TestCaseResponseAllOf
from qaseio.model.test_case_update import TestCaseUpdate
from qaseio.model.test_step import TestStep
from qaseio.model.test_step_create import TestStepCreate
from qaseio.model.test_step_result import TestStepResult
from qaseio.model.test_step_result_create import TestStepResultCreate



"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.create_result200_response_all_of import CreateResult200ResponseAllOf
from qaseio.model.create_result200_response_all_of_result import CreateResult200ResponseAllOfResult
from qaseio.model.response import Response
globals()['CreateResult200ResponseAllOf'] = CreateResult200ResponseAllOf
globals()['CreateResult200ResponseAllOfResult'] = CreateResult200ResponseAllOfResult
globals()['Response'] = Response
from qaseio.model.create_result200_response import CreateResult200Response


class TestCreateResult200Response(unittest.TestCase):
    """CreateResult200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateResult200Response(self):
        """Test CreateResult200Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateResult200Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from qaseio.api_client import ApiClient, Endpoint as _Endpoint
from qaseio.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from qaseio.model.id_response import IdResponse
from qaseio.model.response import Response
from qaseio.model.run_create import RunCreate
from qaseio.model.run_list_response import RunListResponse
from qaseio.model.run_public import RunPublic
from qaseio.model.run_public_response import RunPublicResponse
from qaseio.model.run_response import RunResponse


class RunsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.complete_run_endpoint = _Endpoint(
            settings={
                'response_type': (Response,),
                'auth': [
                    'TokenAuth'
                ],
                'endpoint_path': '/run/{code}/{id}/complete',
                'operation_id': 'complete_run',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'id',
                ],
                'required': [
                    'code',
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 10,
                        'min_length': 2,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'id':
                        (int,),
                },
                'attribute_map': {
                    'code': 'code',
                    'id': 'id',
                },
                'location_map': {
                    'code': 'path',
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.create_run_endpoint = _Endpoint(
            settings={
                'response_type': (IdResponse,),
                'auth': [
                    'TokenAuth'
                ],
                'endpoint_path': '/run/{code}',
                'operation_id': 'create_run',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'run_create',
                ],
                'required': [
                    'code',
                    'run_create',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 10,
                        'min_length': 2,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'run_create':
                        (RunCreate,),
                },
                'attribute_map': {
                    'code': 'code',
                },
                'location_map': {
                    'code': 'path',
                    'run_create': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_run_endpoint = _Endpoint(
            settings={
                'response_type': (IdResponse,),
                'auth': [
                    'TokenAuth'
                ],
                'endpoint_path': '/run/{code}/{id}',
                'operation_id': 'delete_run',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'id',
                ],
                'required': [
                    'code',
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 10,
                        'min_length': 2,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'id':
                        (int,),
                },
                'attribute_map': {
                    'code': 'code',
                    'id': 'id',
                },
                'location_map': {
                    'code': 'path',
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_run_endpoint = _Endpoint(
            settings={
                'response_type': (RunResponse,),
                'auth': [
                    'TokenAuth'
                ],
                'endpoint_path': '/run/{code}/{id}',
                'operation_id': 'get_run',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'id',
                    'include',
                ],
                'required': [
                    'code',
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 10,
                        'min_length': 2,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'id':
                        (int,),
                    'include':
                        (str,),
                },
                'attribute_map': {
                    'code': 'code',
                    'id': 'id',
                    'include': 'include',
                },
                'location_map': {
                    'code': 'path',
                    'id': 'path',
                    'include': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_runs_endpoint = _Endpoint(
            settings={
                'response_type': (RunListResponse,),
                'auth': [
                    'TokenAuth'
                ],
                'endpoint_path': '/run/{code}',
                'operation_id': 'get_runs',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'search',
                    'status',
                    'milestone',
                    'environment',
                    'from_start_time',
                    'to_start_time',
                    'limit',
                    'offset',
                    'include',
                ],
                'required': [
                    'code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                    'limit',
                    'offset',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 10,
                        'min_length': 2,
                    },
                    ('limit',): {

                        'inclusive_maximum': 100,
                        'inclusive_minimum': 1,
                    },
                    ('offset',): {

                        'inclusive_maximum': 100000,
                        'inclusive_minimum': 0,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'search':
                        (str,),
                    'status':
                        (str,),
                    'milestone':
                        (int,),
                    'environment':
                        (int,),
                    'from_start_time':
                        (int,),
                    'to_start_time':
                        (int,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                    'include':
                        (str,),
                },
                'attribute_map': {
                    'code': 'code',
                    'search': 'search',
                    'status': 'status',
                    'milestone': 'milestone',
                    'environment': 'environment',
                    'from_start_time': 'from_start_time',
                    'to_start_time': 'to_start_time',
                    'limit': 'limit',
                    'offset': 'offset',
                    'include': 'include',
                },
                'location_map': {
                    'code': 'path',
                    'search': 'query',
                    'status': 'query',
                    'milestone': 'query',
                    'environment': 'query',
                    'from_start_time': 'query',
                    'to_start_time': 'query',
                    'limit': 'query',
                    'offset': 'query',
                    'include': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_run_publicity_endpoint = _Endpoint(
            settings={
                'response_type': (RunPublicResponse,),
                'auth': [
                    'TokenAuth'
                ],
                'endpoint_path': '/run/{code}/{id}/public',
                'operation_id': 'update_run_publicity',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'id',
                    'run_public',
                ],
                'required': [
                    'code',
                    'id',
                    'run_public',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 10,
                        'min_length': 2,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'id':
                        (int,),
                    'run_public':
                        (RunPublic,),
                },
                'attribute_map': {
                    'code': 'code',
                    'id': 'id',
                },
                'location_map': {
                    'code': 'path',
                    'id': 'path',
                    'run_public': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def complete_run(
        self,
        code,
        id,
        **kwargs
    ):
        """Complete a specific run.  # noqa: E501

        This method allows to complete a specific run.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.complete_run(code, id, async_req=True)
        >>> result = thread.get()

        Args:
            code (str): Code of project, where to search entities.
            id (int): Identifier.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Response
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        kwargs['id'] = \
            id
        return self.complete_run_endpoint.call_with_http_info(**kwargs)

    def create_run(
        self,
        code,
        run_create,
        **kwargs
    ):
        """Create a new run.  # noqa: E501

        This method allows to create a run in selected project.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_run(code, run_create, async_req=True)
        >>> result = thread.get()

        Args:
            code (str): Code of project, where to search entities.
            run_create (RunCreate):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            IdResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        kwargs['run_create'] = \
            run_create
        return self.create_run_endpoint.call_with_http_info(**kwargs)

    def delete_run(
        self,
        code,
        id,
        **kwargs
    ):
        """Delete run.  # noqa: E501

        This method completely deletes a run from repository.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_run(code, id, async_req=True)
        >>> result = thread.get()

        Args:
            code (str): Code of project, where to search entities.
            id (int): Identifier.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            IdResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        kwargs['id'] = \
            id
        return self.delete_run_endpoint.call_with_http_info(**kwargs)

    def get_run(
        self,
        code,
        id,
        **kwargs
    ):
        """Get a specific run.  # noqa: E501

        This method allows to retrieve a specific run.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_run(code, id, async_req=True)
        >>> result = thread.get()

        Args:
            code (str): Code of project, where to search entities.
            id (int): Identifier.

        Keyword Args:
            include (str): Include a list of related entities IDs into response. Should be separated by comma. Possible values: cases, defects . [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            RunResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        kwargs['id'] = \
            id
        return self.get_run_endpoint.call_with_http_info(**kwargs)

    def get_runs(
        self,
        code,
        **kwargs
    ):
        """Get all runs.  # noqa: E501

        This method allows to retrieve all runs stored in selected project.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_runs(code, async_req=True)
        >>> result = thread.get()

        Args:
            code (str): Code of project, where to search entities.

        Keyword Args:
            search (str): [optional]
            status (str): A list of status values separated by comma. Possible values: active, complete, abort. . [optional]
            milestone (int): [optional]
            environment (int): [optional]
            from_start_time (int): [optional]
            to_start_time (int): [optional]
            limit (int): A number of entities in result set.. [optional] if omitted the server will use the default value of 10
            offset (int): How many entities should be skipped.. [optional] if omitted the server will use the default value of 0
            include (str): Include a list of related entities IDs into response. Should be separated by comma. Possible values: cases, defects . [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            RunListResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        return self.get_runs_endpoint.call_with_http_info(**kwargs)

    def update_run_publicity(
        self,
        code,
        id,
        run_public,
        **kwargs
    ):
        """Update publicity of a specific run.  # noqa: E501

        This method allows to update a publicity of specific run.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_run_publicity(code, id, run_public, async_req=True)
        >>> result = thread.get()

        Args:
            code (str): Code of project, where to search entities.
            id (int): Identifier.
            run_public (RunPublic):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            RunPublicResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        kwargs['id'] = \
            id
        kwargs['run_public'] = \
            run_public
        return self.update_run_publicity_endpoint.call_with_http_info(**kwargs)




"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.custom_field_value import CustomFieldValue
from qaseio.model.run_environment import RunEnvironment
from qaseio.model.run_milestone import RunMilestone
from qaseio.model.run_stats import RunStats
from qaseio.model.tag_value import TagValue
globals()['CustomFieldValue'] = CustomFieldValue
globals()['RunEnvironment'] = RunEnvironment
globals()['RunMilestone'] = RunMilestone
globals()['RunStats'] = RunStats
globals()['TagValue'] = TagValue
from qaseio.model.run import Run


class TestRun(unittest.TestCase):
    """Run unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRun(self):
        """Test Run"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Run()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.milestone import Milestone
from qaseio.model.milestone_response_all_of import MilestoneResponseAllOf
from qaseio.model.response import Response
globals()['Milestone'] = Milestone
globals()['MilestoneResponseAllOf'] = MilestoneResponseAllOf
globals()['Response'] = Response
from qaseio.model.milestone_response import MilestoneResponse


class TestMilestoneResponse(unittest.TestCase):
    """MilestoneResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMilestoneResponse(self):
        """Test MilestoneResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MilestoneResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import qaseio
from qaseio.api.authors_api import AuthorsApi  # noqa: E501


class TestAuthorsApi(unittest.TestCase):
    """AuthorsApi unit test stubs"""

    def setUp(self):
        self.api = AuthorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_author(self):
        """Test case for get_author

        Get a specific author.  # noqa: E501
        """
        pass

    def test_get_authors(self):
        """Test case for get_authors

        Get all authors.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.author import Author
from qaseio.model.author_response_all_of import AuthorResponseAllOf
from qaseio.model.response import Response
globals()['Author'] = Author
globals()['AuthorResponseAllOf'] = AuthorResponseAllOf
globals()['Response'] = Response
from qaseio.model.author_response import AuthorResponse


class TestAuthorResponse(unittest.TestCase):
    """AuthorResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAuthorResponse(self):
        """Test AuthorResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AuthorResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.author_list_response_all_of import AuthorListResponseAllOf
from qaseio.model.author_list_response_all_of_result import AuthorListResponseAllOfResult
from qaseio.model.response import Response
globals()['AuthorListResponseAllOf'] = AuthorListResponseAllOf
globals()['AuthorListResponseAllOfResult'] = AuthorListResponseAllOfResult
globals()['Response'] = Response
from qaseio.model.author_list_response import AuthorListResponse


class TestAuthorListResponse(unittest.TestCase):
    """AuthorListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAuthorListResponse(self):
        """Test AuthorListResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AuthorListResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from qaseio.api_client import ApiClient, Endpoint as _Endpoint
from qaseio.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from qaseio.model.bulk200_response import Bulk200Response
from qaseio.model.bulk_request import BulkRequest
from qaseio.model.id_response import IdResponse
from qaseio.model.test_case_create import TestCaseCreate
from qaseio.model.test_case_list_response import TestCaseListResponse
from qaseio.model.test_case_response import TestCaseResponse
from qaseio.model.test_case_update import TestCaseUpdate


class CasesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.bulk_endpoint = _Endpoint(
            settings={
                'response_type': (Bulk200Response,),
                'auth': [
                    'TokenAuth'
                ],
                'endpoint_path': '/case/{code}/bulk',
                'operation_id': 'bulk',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'bulk_request',
                ],
                'required': [
                    'code',
                    'bulk_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 10,
                        'min_length': 2,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'bulk_request':
                        (BulkRequest,),
                },
                'attribute_map': {
                    'code': 'code',
                },
                'location_map': {
                    'code': 'path',
                    'bulk_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.create_case_endpoint = _Endpoint(
            settings={
                'response_type': (IdResponse,),
                'auth': [
                    'TokenAuth'
                ],
                'endpoint_path': '/case/{code}',
                'operation_id': 'create_case',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'test_case_create',
                ],
                'required': [
                    'code',
                    'test_case_create',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 10,
                        'min_length': 2,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'test_case_create':
                        (TestCaseCreate,),
                },
                'attribute_map': {
                    'code': 'code',
                },
                'location_map': {
                    'code': 'path',
                    'test_case_create': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_case_endpoint = _Endpoint(
            settings={
                'response_type': (IdResponse,),
                'auth': [
                    'TokenAuth'
                ],
                'endpoint_path': '/case/{code}/{id}',
                'operation_id': 'delete_case',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'id',
                ],
                'required': [
                    'code',
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 10,
                        'min_length': 2,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'id':
                        (int,),
                },
                'attribute_map': {
                    'code': 'code',
                    'id': 'id',
                },
                'location_map': {
                    'code': 'path',
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_case_endpoint = _Endpoint(
            settings={
                'response_type': (TestCaseResponse,),
                'auth': [
                    'TokenAuth'
                ],
                'endpoint_path': '/case/{code}/{id}',
                'operation_id': 'get_case',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'id',
                ],
                'required': [
                    'code',
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 10,
                        'min_length': 2,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'id':
                        (int,),
                },
                'attribute_map': {
                    'code': 'code',
                    'id': 'id',
                },
                'location_map': {
                    'code': 'path',
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_cases_endpoint = _Endpoint(
            settings={
                'response_type': (TestCaseListResponse,),
                'auth': [
                    'TokenAuth'
                ],
                'endpoint_path': '/case/{code}',
                'operation_id': 'get_cases',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'search',
                    'milestone_id',
                    'suite_id',
                    'severity',
                    'priority',
                    'type',
                    'behavior',
                    'automation',
                    'status',
                    'limit',
                    'offset',
                ],
                'required': [
                    'code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                    'limit',
                    'offset',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 10,
                        'min_length': 2,
                    },
                    ('limit',): {

                        'inclusive_maximum': 100,
                        'inclusive_minimum': 1,
                    },
                    ('offset',): {

                        'inclusive_maximum': 100000,
                        'inclusive_minimum': 0,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'search':
                        (str,),
                    'milestone_id':
                        (int,),
                    'suite_id':
                        (int,),
                    'severity':
                        (str,),
                    'priority':
                        (str,),
                    'type':
                        (str,),
                    'behavior':
                        (str,),
                    'automation':
                        (str,),
                    'status':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                },
                'attribute_map': {
                    'code': 'code',
                    'search': 'search',
                    'milestone_id': 'milestone_id',
                    'suite_id': 'suite_id',
                    'severity': 'severity',
                    'priority': 'priority',
                    'type': 'type',
                    'behavior': 'behavior',
                    'automation': 'automation',
                    'status': 'status',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'code': 'path',
                    'search': 'query',
                    'milestone_id': 'query',
                    'suite_id': 'query',
                    'severity': 'query',
                    'priority': 'query',
                    'type': 'query',
                    'behavior': 'query',
                    'automation': 'query',
                    'status': 'query',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_case_endpoint = _Endpoint(
            settings={
                'response_type': (IdResponse,),
                'auth': [
                    'TokenAuth'
                ],
                'endpoint_path': '/case/{code}/{id}',
                'operation_id': 'update_case',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'id',
                    'test_case_update',
                ],
                'required': [
                    'code',
                    'id',
                    'test_case_update',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'code',
                ]
            },
            root_map={
                'validations': {
                    ('code',): {
                        'max_length': 10,
                        'min_length': 2,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'id':
                        (int,),
                    'test_case_update':
                        (TestCaseUpdate,),
                },
                'attribute_map': {
                    'code': 'code',
                    'id': 'id',
                },
                'location_map': {
                    'code': 'path',
                    'id': 'path',
                    'test_case_update': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def bulk(
        self,
        code,
        bulk_request,
        **kwargs
    ):
        """Create test cases in bulk.  # noqa: E501

        This method allows to bulk create new test cases in a project.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bulk(code, bulk_request, async_req=True)
        >>> result = thread.get()

        Args:
            code (str): Code of project, where to search entities.
            bulk_request (BulkRequest):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Bulk200Response
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        kwargs['bulk_request'] = \
            bulk_request
        return self.bulk_endpoint.call_with_http_info(**kwargs)

    def create_case(
        self,
        code,
        test_case_create,
        **kwargs
    ):
        """Create a new test case.  # noqa: E501

        This method allows to create a new test case in selected project.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_case(code, test_case_create, async_req=True)
        >>> result = thread.get()

        Args:
            code (str): Code of project, where to search entities.
            test_case_create (TestCaseCreate):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            IdResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        kwargs['test_case_create'] = \
            test_case_create
        return self.create_case_endpoint.call_with_http_info(**kwargs)

    def delete_case(
        self,
        code,
        id,
        **kwargs
    ):
        """Delete test case.  # noqa: E501

        This method completely deletes a test case from repository.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_case(code, id, async_req=True)
        >>> result = thread.get()

        Args:
            code (str): Code of project, where to search entities.
            id (int): Identifier.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            IdResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        kwargs['id'] = \
            id
        return self.delete_case_endpoint.call_with_http_info(**kwargs)

    def get_case(
        self,
        code,
        id,
        **kwargs
    ):
        """Get a specific test case.  # noqa: E501

        This method allows to retrieve a specific test case.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_case(code, id, async_req=True)
        >>> result = thread.get()

        Args:
            code (str): Code of project, where to search entities.
            id (int): Identifier.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            TestCaseResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        kwargs['id'] = \
            id
        return self.get_case_endpoint.call_with_http_info(**kwargs)

    def get_cases(
        self,
        code,
        **kwargs
    ):
        """Get all test cases.  # noqa: E501

        This method allows to retrieve all test cases stored in selected project.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_cases(code, async_req=True)
        >>> result = thread.get()

        Args:
            code (str): Code of project, where to search entities.

        Keyword Args:
            search (str): Provide a string that will be used to search by name.. [optional]
            milestone_id (int): ID of milestone.. [optional]
            suite_id (int): ID of test suite.. [optional]
            severity (str): A list of severity values separated by comma. Possible values: undefined, blocker, critical, major, normal, minor, trivial . [optional]
            priority (str): A list of priority values separated by comma. Possible values: undefined, high, medium, low . [optional]
            type (str): A list of type values separated by comma. Possible values: other, functional smoke, regression, security, usability, performance, acceptance . [optional]
            behavior (str): A list of behavior values separated by comma. Possible values: undefined, positive negative, destructive . [optional]
            automation (str): A list of values separated by comma. Possible values: is-not-automated, automated to-be-automated . [optional]
            status (str): A list of values separated by comma. Possible values: actual, draft deprecated . [optional]
            limit (int): A number of entities in result set.. [optional] if omitted the server will use the default value of 10
            offset (int): How many entities should be skipped.. [optional] if omitted the server will use the default value of 0
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            TestCaseListResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        return self.get_cases_endpoint.call_with_http_info(**kwargs)

    def update_case(
        self,
        code,
        id,
        test_case_update,
        **kwargs
    ):
        """Update test case.  # noqa: E501

        This method updates a test case.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_case(code, id, test_case_update, async_req=True)
        >>> result = thread.get()

        Args:
            code (str): Code of project, where to search entities.
            id (int): Identifier.
            test_case_update (TestCaseUpdate):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            IdResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        kwargs['id'] = \
            id
        kwargs['test_case_update'] = \
            test_case_update
        return self.update_case_endpoint.call_with_http_info(**kwargs)




"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.milestone_list_response_all_of import MilestoneListResponseAllOf
from qaseio.model.milestone_list_response_all_of_result import MilestoneListResponseAllOfResult
from qaseio.model.response import Response
globals()['MilestoneListResponseAllOf'] = MilestoneListResponseAllOf
globals()['MilestoneListResponseAllOfResult'] = MilestoneListResponseAllOfResult
globals()['Response'] = Response
from qaseio.model.milestone_list_response import MilestoneListResponse


class TestMilestoneListResponse(unittest.TestCase):
    """MilestoneListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMilestoneListResponse(self):
        """Test MilestoneListResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MilestoneListResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import qaseio
from qaseio.api.result_api import ResultApi  # noqa: E501


class TestResultApi(unittest.TestCase):
    """ResultApi unit test stubs"""

    def setUp(self):
        self.api = ResultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_results_v2(self):
        """Test case for create_results_v2

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.result_attachment import ResultAttachment
from qaseio.model.result_execution import ResultExecution
from qaseio.model.result_relations import ResultRelations
from qaseio.model.result_step import ResultStep
globals()['ResultAttachment'] = ResultAttachment
globals()['ResultExecution'] = ResultExecution
globals()['ResultRelations'] = ResultRelations
globals()['ResultStep'] = ResultStep
from qaseio.model.create_results_request_v2_results_inner import CreateResultsRequestV2ResultsInner


class TestCreateResultsRequestV2ResultsInner(unittest.TestCase):
    """CreateResultsRequestV2ResultsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateResultsRequestV2ResultsInner(self):
        """Test CreateResultsRequestV2ResultsInner"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateResultsRequestV2ResultsInner()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
